@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '1.39'; # VERSION
+our $DATE = '2016-08-03'; # DATE
+our $VERSION = '1.40'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1245,22 +1245,6 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
             {
                 name => 'config file',
                 before_all_tests => sub {
-                    # old syntax, Perinci::CmdLine::Lite < 1.42. will not be
-                    # supported in the future
-                    write_text("$tempdir/prog-old.conf", <<'_');
-a=101
-b=201
-[subcommand1]
-a=102
-c=201
-[subcommand2]
-a=103
-[profile=profile1]
-a=111
-d=201
-[subcommand1 profile=profile1]
-a=121
-_
                     write_text("$tempdir/prog.conf", <<'_');
 a=101
 b=201
@@ -1285,6 +1269,19 @@ _
 format=json
 naked_res=1
 a.arg=101
+_
+                    write_text("$tempdir/prog4.conf", <<'_');
+a=300
+b=301
+[prog]
+a=302
+b=303
+[prog2]
+a=304
+b=305
+[prog profile=profile1]
+a=306
+b=307
 _
                 },
                 tests => [
@@ -1315,6 +1312,34 @@ _
                         argv        => [],
                         stdout_like => qr/^a=104\nb=\nc=\nd=\ne=$/,
                     },
+                    {
+                        tags        => ['config-file'],
+                        name        => 'attr:config_filename (hash record)',
+                        gen_args    => {
+                            url => '/Perinci/Examples/noop2',
+                            script_name => 'prog',
+                            read_config => 1,
+                            config_dirs => [$tempdir],
+                            config_filename => [{filename=>'prog4.conf', section=>'prog'}, 'prog2.conf'],
+                        },
+                        #inline_gen_args => {...},
+                        argv        => [],
+                        stdout_like => qr/^a=104\nb=303\nc=\nd=\ne=$/,
+                    },
+                    {
+                        tags        => ['config-file'],
+                        name        => 'attr:config_filename (hash record) + --config-profile',
+                        gen_args    => {
+                            url => '/Perinci/Examples/noop2',
+                            script_name => 'prog',
+                            read_config => 1,
+                            config_dirs => [$tempdir],
+                            config_filename => [{filename=>'prog4.conf', section=>'prog'}, 'prog2.conf'],
+                        },
+                        #inline_gen_args => {...},
+                        argv        => [qw/--config-profile profile1/],
+                        stdout_like => qr/^a=104\nb=307\nc=\nd=\ne=$/,
+                    },
                     {
                         tags        => ['config-file'],
                         name        => 'common option: --no-config',
@@ -1410,24 +1435,6 @@ _
                         stdout_like => qr/^a=102\nb=201\nc=201\nd=\ne=$/,
                     },
 
-                    # this test will be removed in the future
-                    {
-                        tags        => ['config-file', 'subcommand'],
-                        name        => 'subcommand + --config-profile (old syntax)',
-                        gen_args => {
-                            url => '/Perinci/Examples/',
-                            subcommands => [
-                                'subcommand1:/Perinci/Examples/noop2',
-                            ],
-                            script_name => 'prog-old',
-                            read_config => 1,
-                            config_dirs => [$tempdir],
-                        },
-                        #inline_gen_args => {...},
-                        argv        => [qw/--config-profile=profile1 subcommand1/],
-                        stdout_like => qr/^a=121\nb=201\nc=201\nd=201\ne=$/,
-                    },
-
                     {
                         tags        => ['config-file', 'subcommand'],
                         name        => 'subcommand + --config-profile',
@@ -1497,7 +1504,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.39 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-02-26.
+This document describes version 1.40 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2016-08-03.
 
 =head1 FUNCTIONS
 
@@ -1538,7 +1545,7 @@ Return value:  (any)
 
 Run groups of Perinci::CmdLine tests.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
